@@ -33,7 +33,7 @@ def _get_popen_cmd(command: str) -> List[str]:
         command_extra = "\n".join(options) + "\n" + command_extra
         popen_cmd = ["/bin/bash", "--rcfile", "/dev/null", "-c", command_extra]
     elif is_darwin():
-        options = ["set -uo pipefail", "setopt +o nomatch"]
+        options = ["set -uo pipefail"]
         command_extra = "\n".join(options) + "\n" + command_extra
         popen_cmd = ["/bin/zsh", "-c", command_extra]
     else:
