@@ -1,3 +1,4 @@
+import builtins
 import os
 import sys
 from contextlib import contextmanager
@@ -82,6 +83,7 @@ class BaseVenv:
         if path not in environ.path:
             environ.path.insert(0, path)
 
+        builtins.__xonsh__.env.update(environ.get_env_vars())
         environ.save_to_os_environ()
 
     def deactivate(self, e: Optional[Env.Environ] = None) -> None:
@@ -89,6 +91,7 @@ class BaseVenv:
         if self._get_path() in environ.path:
             environ.path.remove(self._get_path())
 
+        builtins.__xonsh__.env.update(environ.get_env_vars())
         environ.save_to_os_environ()
 
     def __enter__(self) -> None:
